## changes on 0.4.0

removed creation of user accounts

## changes on 0.3.2

bugfix in spawner

## changes on 0.3.1

A pamela-login is executed before spawning a notebook server

## changes on 0.2.6

* method logout_url() removed

